package stx.libjava.tests;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URL;
import java.net.URLClassLoader;

import org.junit.Test;

import stx.libjava.tests.mocks.EyeOpeningClassLoader;
import stx.libjava.tests.mocks.MeanClassLoader;

@SuppressWarnings("rawtypes")
public class ClassLoadersTest {

	@Test
	public void testSystemClassLoader() throws Exception {
		ClassLoader cl = ClassLoader.getSystemClassLoader();
		Class clazz = cl.loadClass("org.junit.Test");
		assertNotNull(clazz);
		assertEquals(cl, clazz.getClassLoader());
	}

	@Test
	public void testSystemClassLoaderLoadingRTClass() throws Exception {
		ClassLoader cl = ClassLoader.getSystemClassLoader();
		Class clazz = cl.loadClass("java.util.ArrayList");
		assertNotNull(clazz);
		assertNull(clazz.getClassLoader());
	}

	@Test
	public void testNiceClassLoaderDelegation() throws Exception {
		URL[] urls = new URL[1];
		File file = new File("foos");
		urls[0] = file.toURL();
		URLClassLoader cl = new URLClassLoader(urls);
		Class result = Class.forName("org.junit.Test", true, cl);
		assertEquals(result.getClassLoader(),
				ClassLoader.getSystemClassLoader());
	}

	@Test
	public void testNiceClassLoaderSelfLoading() throws Exception {
		URL[] urls = new URL[1];
		File file = new File("foos");
		urls[0] = file.toURL();
		URLClassLoader cl = new URLClassLoader(urls);
		Class result = Class.forName("Foo", true, cl);
		assertEquals(cl, result.getClassLoader());
	}

	@Test
	public void testMeanClassLoaderSelfLoading() throws Exception {
		MeanClassLoader cl = new MeanClassLoader();
		Class result = Class.forName("org.junit.Test", true, cl);
		assertEquals(result.getClassLoader(), cl);
	}

	@Test
	public void testEyeOpeningClassLoaderLoadObject() throws Exception {
		try {
			EyeOpeningClassLoader cl = new EyeOpeningClassLoader();
			cl.tryToLoadObject();
			assertTrue(false);
		} catch (SecurityException e) {
			assertTrue(true);
		}
	}

	@Test
	public void testEyeOpeningClassLoaderLoadRuntimeException()
			throws Exception {
		try {
			EyeOpeningClassLoader cl = new EyeOpeningClassLoader();
			cl.tryToLoadRuntimeException();
			assertTrue(false);
		} catch (SecurityException e) {
			assertTrue(true);
		}
	}

	@Test
	public void testEyeOpeningClassLoaderLoadMethod() throws Exception {
		try {
			EyeOpeningClassLoader cl = new EyeOpeningClassLoader();
			cl.tryToLoadMethod();
			assertTrue(false);
		} catch (SecurityException e) {
			assertTrue(true);
		}
	}

	@Test
	public void testEyeOpeningClassLoaderLoadString() throws Exception {
		try {
			EyeOpeningClassLoader cl = new EyeOpeningClassLoader();
			cl.tryToLoadString();
			assertTrue(false);
		} catch (SecurityException e) {
			assertTrue(true);
		}
	}

	@Test
	public void testEyeOpeningClassLoaderLoadDatasource() throws Exception {
		try {
			EyeOpeningClassLoader cl = new EyeOpeningClassLoader();
			cl.tryToLoadDatasource();
			// no exception should be raised
		} catch (NullPointerException e) {
			// it will fail on internals, but we only care about security
			// exception
		}
		assertTrue(true);
	}

	@Test
	public void testEyeOpeningClassLoaderLoadBits() throws Exception {
		try {
			EyeOpeningClassLoader cl = new EyeOpeningClassLoader();
			cl.tryToLoadBits();
			assertTrue(false);
		} catch (SecurityException e) {
			assertTrue(true);
		}
	}

	@Test
	public void testEyeOpeningClassLoaderLoadArray() throws Exception {
		try {
			EyeOpeningClassLoader cl = new EyeOpeningClassLoader();
			cl.tryToLoadArray();
			assertTrue(false);
		} catch (SecurityException e) {
			assertTrue(true);
		}
	}
}
