package stx.libjava.tests;

import static org.junit.Assert.assertNotSame;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertEquals;

import org.junit.Test;
@SuppressWarnings("rawtypes")
public class ClassLoadingTest {

	@Test
	public void testBootstrapClassLoader() throws Exception {	
		Class clazz = Class.forName("java.lang.Object");
		assertTrue(clazz.getClassLoader() == null);
		System.out.println(System.getProperty("sun.boot.class.path"));
		System.out.println(System.getProperty("java.ext.dirs"));
	}
	
	@Test
	public void testSystemClassLoader() throws Exception {
		Class clazz = Class.forName("org.junit.Test");
		assertTrue(clazz.getClassLoader().equals(ClassLoader.getSystemClassLoader()));
	}
	
	@Test
	public void testSystemClassLoader2() throws Exception {
		Class clazz = Class.forName("org.hamcrest.Factory");
		assertTrue(clazz.getClassLoader().equals(ClassLoader.getSystemClassLoader()));
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromRT() throws Exception {
		Class clazz = Class.forName("javax.sql.DataSource");
		assertTrue(clazz.getClassLoader() == null);
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromRT2() throws Exception {
		Class clazz = Class.forName("org.xml.sax.Parser");
		assertTrue(clazz.getClassLoader() == null);
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromJavaRelease() throws Exception {
		Class clazz = Class.forName("sun.io.CharToByteDoubleByte");
		assertTrue(clazz.getClassLoader() == null);
	}
	
	@Test
	public void testBootstrapCLLoadsNOTEverythingFromJavaRelease2() throws Exception {
		Class clazz = Class.forName("sun.net.spi.nameservice.dns.DNSNameService");
		ClassLoader expected = ClassLoader.getSystemClassLoader();
		ClassLoader real = clazz.getClassLoader();		
		assertEquals(expected.getParent(), real);
		//WEIRD..
		assertNotSame(expected,real);
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromJavaRelease3() throws Exception {
		Class clazz = Class.forName("javax.net.SocketFactory");
		ClassLoader real = clazz.getClassLoader();
		assertNull(real);
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromJavaRelease4() throws Exception {
		Class clazz = Class.forName("com.sun.net.ssl.TrustManager");
		ClassLoader real = clazz.getClassLoader();
		assertNull(real);
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromJavaRelease5() throws Exception {
		Class clazz = Class.forName("javax.crypto.Cipher");
		ClassLoader real = clazz.getClassLoader();
		assertNull(real);
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromJavaRelease6() throws Exception {
		Class clazz = Class.forName("sun.security.internal.spec.TlsKeyMaterialParameterSpec");
		ClassLoader real = clazz.getClassLoader();
		assertNull(real);
	}
	
	@Test
	public void testBootstrapCLLoadsEverythingFromJavaRelease7() throws Exception {
		Class clazz = Class.forName("java.lang.Thread");
		assertTrue(clazz.getClassLoader() == null);
	}
	
	@Test
	public void testSystemClassLoaderClassLoader() throws Exception {		
		Class clazz = ClassLoader.getSystemClassLoader().getClass();
		ClassLoader real = clazz.getClassLoader();
		assertNull(real);
	}
	
	@Test
	public void testSystemClassLoaderParentClassLoader() throws Exception {		
		Class clazz = ClassLoader.getSystemClassLoader().getParent().getClass();
		ClassLoader real = clazz.getClassLoader();
		assertNull(real);
	}
	
	
	
	@Test
	public void testWeirdDNSClassLoader() throws Exception {
		Class clazz = Class.forName("sun.net.spi.nameservice.dns.DNSNameService");
		ClassLoader real = clazz.getClassLoader().getParent();
		assertNull(real);
	}
	
	
	
}
